@@ -29,8 +29,8 @@ gs_plugins_core_search_repo_name_func (GsPluginLoader *plugin_loader)
 	gs_plugin_loader_setup_again (plugin_loader);
 
 	/* force this app to be installed */
-	app_tmp = gs_plugin_loader_app_create (plugin_loader, "*/*/yellow/desktop/arachne.desktop/*");
-	gs_app_set_state (app_tmp, AS_APP_STATE_INSTALLED);
+	app_tmp = gs_plugin_loader_app_create (plugin_loader, "*/*/yellow/arachne.desktop/*");
+	gs_app_set_state (app_tmp, GS_APP_STATE_INSTALLED);
 
 	/* get search result based on addon keyword */
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_SEARCH,
@@ -46,7 +46,7 @@ gs_plugins_core_search_repo_name_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpint (gs_app_list_length (list), ==, 1);
 	app = gs_app_list_index (list, 0);
 	g_assert_cmpstr (gs_app_get_id (app), ==, "arachne.desktop");
-	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_DESKTOP);
+	g_assert_cmpint (gs_app_get_kind (app), ==, AS_COMPONENT_KIND_DESKTOP_APP);
 }
 
 static void
@@ -76,8 +76,8 @@ gs_plugins_core_os_release_func (GsPluginLoader *plugin_loader)
 
 	/* make sure there is valid content */
 	g_assert_cmpstr (gs_app_get_id (app), ==, "org.fedoraproject.Fedora-25");
-	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_OS_UPGRADE);
-	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_INSTALLED);
+	g_assert_cmpint (gs_app_get_kind (app), ==, AS_COMPONENT_KIND_OPERATING_SYSTEM);
+	g_assert_cmpint (gs_app_get_state (app), ==, GS_APP_STATE_INSTALLED);
 	g_assert_cmpstr (gs_app_get_name (app), ==, "Fedora");
 	g_assert_cmpstr (gs_app_get_version (app), ==, "25");
 	g_assert_cmpstr (gs_app_get_url (app, AS_URL_KIND_HOMEPAGE), ==,
@@ -117,14 +117,14 @@ gs_plugins_core_generic_updates_func (GsPluginLoader *plugin_loader)
 	list = gs_app_list_new ();
 	app1 = gs_app_new ("package1");
 	app2 = gs_app_new ("package2");
-	gs_app_set_kind (app1, AS_APP_KIND_GENERIC);
-	gs_app_set_kind (app2, AS_APP_KIND_GENERIC);
+	gs_app_set_kind (app1, AS_COMPONENT_KIND_GENERIC);
+	gs_app_set_kind (app2, AS_COMPONENT_KIND_GENERIC);
 	gs_app_set_bundle_kind (app1, AS_BUNDLE_KIND_PACKAGE);
 	gs_app_set_bundle_kind (app2, AS_BUNDLE_KIND_PACKAGE);
-	gs_app_set_scope (app1, AS_APP_SCOPE_SYSTEM);
-	gs_app_set_scope (app2, AS_APP_SCOPE_SYSTEM);
-	gs_app_set_state (app1, AS_APP_STATE_UPDATABLE);
-	gs_app_set_state (app2, AS_APP_STATE_UPDATABLE);
+	gs_app_set_scope (app1, AS_COMPONENT_SCOPE_SYSTEM);
+	gs_app_set_scope (app2, AS_COMPONENT_SCOPE_SYSTEM);
+	gs_app_set_state (app1, GS_APP_STATE_UPDATABLE);
+	gs_app_set_state (app2, GS_APP_STATE_UPDATABLE);
 	gs_app_add_source (app1, "package1");
 	gs_app_add_source (app2, "package2");
 	gs_app_list_add (list, app1);
@@ -146,7 +146,8 @@ gs_plugins_core_generic_updates_func (GsPluginLoader *plugin_loader)
 
 	/* make sure the os update is valid */
 	g_assert_cmpstr (gs_app_get_id (os_update), ==, "org.gnome.Software.OsUpdate");
-	g_assert_cmpint (gs_app_get_kind (os_update), ==, AS_APP_KIND_OS_UPDATE);
+	g_assert_cmpint (gs_app_get_kind (os_update), ==, AS_COMPONENT_KIND_GENERIC);
+	g_assert_cmpint (gs_app_get_special_kind (os_update), ==, GS_APP_SPECIAL_KIND_OS_UPDATE);
 	g_assert (gs_app_has_quirk (os_update, GS_APP_QUIRK_IS_PROXY));
 
 	/* must have two related apps, the ones we added earlier */
@@ -157,7 +158,7 @@ gs_plugins_core_generic_updates_func (GsPluginLoader *plugin_loader)
 	list_wildcard = gs_app_list_new ();
 	app_wildcard = gs_app_new ("nosuchapp.desktop");
 	gs_app_add_quirk (app_wildcard, GS_APP_QUIRK_IS_WILDCARD);
-	gs_app_set_kind (app_wildcard, AS_APP_KIND_GENERIC);
+	gs_app_set_kind (app_wildcard, AS_COMPONENT_KIND_GENERIC);
 	gs_app_list_add (list_wildcard, app_wildcard);
 	plugin_job2 = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFINE,
 	                                  "list", list_wildcard,
@@ -171,7 +172,8 @@ gs_plugins_core_generic_updates_func (GsPluginLoader *plugin_loader)
 	/* no OsUpdate item created */
 	for (guint i = 0; i < gs_app_list_length (list_wildcard); i++) {
 		GsApp *app_tmp = gs_app_list_index (list_wildcard, i);
-		g_assert_cmpint (gs_app_get_kind (app_tmp), !=, AS_APP_KIND_OS_UPDATE);
+		g_assert_cmpint (gs_app_get_kind (app_tmp), !=, AS_COMPONENT_KIND_GENERIC);
+		g_assert_cmpint (gs_app_get_special_kind (app_tmp), !=, GS_APP_SPECIAL_KIND_OS_UPDATE);
 		g_assert (!gs_app_has_quirk (app_tmp, GS_APP_QUIRK_IS_PROXY));
 	}
 }
