@@ -55,7 +55,7 @@ gs_plugin_packagekit_refine_add_history (GsApp *app, GVariant *dict)
 
 	/* create new history item with same ID as parent */
 	history = gs_app_new (gs_app_get_id (app));
-	gs_app_set_kind (history, AS_APP_KIND_GENERIC);
+	gs_app_set_kind (history, AS_COMPONENT_KIND_GENERIC);
 	gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
 	gs_app_set_name (history, GS_APP_QUALITY_NORMAL, gs_app_get_name (app));
 
@@ -64,13 +64,13 @@ gs_plugin_packagekit_refine_add_history (GsApp *app, GVariant *dict)
 	g_assert (ret);
 	switch (info_enum) {
 	case PK_INFO_ENUM_INSTALLING:
-		gs_app_set_state (history, AS_APP_STATE_INSTALLED);
+		gs_app_set_state (history, GS_APP_STATE_INSTALLED);
 		break;
 	case PK_INFO_ENUM_REMOVING:
-		gs_app_set_state (history, AS_APP_STATE_AVAILABLE);
+		gs_app_set_state (history, GS_APP_STATE_AVAILABLE);
 		break;
 	case PK_INFO_ENUM_UPDATING:
-		gs_app_set_state (history, AS_APP_STATE_UPDATABLE);
+		gs_app_set_state (history, GS_APP_STATE_UPDATABLE);
 		break;
 	default:
 		g_debug ("ignoring history kind: %s",
@@ -194,15 +194,15 @@ gs_plugin_packagekit_refine (GsPlugin *plugin,
 		if (!ret) {
 			/* make up a fake entry as we know this package was at
 			 * least installed at some point in time */
-			if (gs_app_get_state (app) == AS_APP_STATE_INSTALLED) {
+			if (gs_app_get_state (app) == GS_APP_STATE_INSTALLED) {
 				g_autoptr(GsApp) app_dummy = NULL;
 				app_dummy = gs_app_new (gs_app_get_id (app));
 				gs_plugin_packagekit_set_packaging_format (plugin, app);
 				gs_app_set_metadata (app_dummy, "GnomeSoftware::Creator",
 						     gs_plugin_get_name (plugin));
 				gs_app_set_install_date (app_dummy, GS_APP_INSTALL_DATE_UNKNOWN);
-				gs_app_set_kind (app_dummy, AS_APP_KIND_GENERIC);
-				gs_app_set_state (app_dummy, AS_APP_STATE_INSTALLED);
+				gs_app_set_kind (app_dummy, AS_COMPONENT_KIND_GENERIC);
+				gs_app_set_state (app_dummy, GS_APP_STATE_INSTALLED);
 				gs_app_set_version (app_dummy, gs_app_get_version (app));
 				gs_app_add_history (app, app_dummy);
 			}
