@@ -181,6 +181,7 @@ gs_plugin_app_origin_repo_enable (GsPlugin *plugin,
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
 	g_autoptr(GsPackagekitHelper) helper = gs_packagekit_helper_new (plugin);
+	g_autoptr(GsApp) repo_app = NULL;
 	g_autoptr(PkResults) results = NULL;
 	g_autoptr(PkError) error_code = NULL;
 	const gchar *repo_id;
@@ -219,6 +220,11 @@ gs_plugin_app_origin_repo_enable (GsPlugin *plugin,
 	 * UNAVAILABLE state to AVAILABLE */
 	gs_app_set_state (app, GS_APP_STATE_AVAILABLE);
 
+	/* Construct a simple fake GsApp for the repository, used only by the signal handler */
+	repo_app = gs_app_new (repo_id);
+	gs_app_set_state (repo_app, GS_APP_STATE_INSTALLED);
+	gs_plugin_repository_changed (plugin, repo_app);
+
 	return TRUE;
 }
 
@@ -260,6 +266,8 @@ gs_plugin_repo_enable (GsPlugin *plugin,
 	/* state is known */
 	gs_app_set_state (app, GS_APP_STATE_INSTALLED);
 
+	gs_plugin_repository_changed (plugin, app);
+
 	return TRUE;
 }
 
@@ -499,6 +507,8 @@ gs_plugin_repo_disable (GsPlugin *plugin,
 	/* state is known */
 	gs_app_set_state (app, GS_APP_STATE_AVAILABLE);
 
+	gs_plugin_repository_changed (plugin, app);
+
 	return TRUE;
 }
 
@@ -511,6 +521,7 @@ gs_plugin_app_remove (GsPlugin *plugin,
 	GsPluginData *priv = gs_plugin_get_data (plugin);
 	const gchar *package_id;
 	GPtrArray *source_ids;
+	GsAppList *addons;
 	g_autoptr(GsPackagekitHelper) helper = gs_packagekit_helper_new (plugin);
 	guint i;
 	guint cnt = 0;
@@ -566,6 +577,14 @@ gs_plugin_app_remove (GsPlugin *plugin,
 		return FALSE;
 	}
 
+	/* Make sure addons' state is updated as well */
+	addons = gs_app_get_addons (app);
+	for (i = 0; i < gs_app_list_length (addons); i++) {
+		GsApp *addon = gs_app_list_index (addons, i);
+		if (gs_app_get_state (addon) == GS_APP_STATE_INSTALLED)
+			gs_app_set_state (addon, GS_APP_STATE_UNKNOWN);
+	}
+
 	/* state is not known: we don't know if we can re-install this app */
 	gs_app_set_state (app, GS_APP_STATE_UNKNOWN);
 
